@@ -10,7 +10,6 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#include <netdb.h>
 #if defined(__NetBSD__)
 /* work around incompatibilities between Linux and KAME */
 #define s6_addr32              __u6_addr.__u6_addr32
@@ -38,7 +37,7 @@ int addr_to_ipv6addrstruct(char *addrstring, char *resultstring, ipv6calc_ipv6ad
 	char *addronlystring, *cp, tempstring[NI_MAXHOST];
 	struct in6_addr inet6addr;
 	int scope = 0, expecteditems = 0;
-	int32_t temp[8];
+	unsigned int temp[8];
 	int compat[4];
 
 	sprintf(resultstring, "%s", ""); /* clear result string */
