@@ -2,7 +2,7 @@
 #
 # Testfile for ipv6calc
 #
-# Version:     $Id: test_ipv6calc.sh,v 0.16 2001/03/13 $
+# Version:     $Id: test_ipv6calc.sh,v 0.20 2001/04/08 $
 #
 # Author:      Peter Bieringer <pb@bieringer.de>
 #
@@ -48,8 +48,13 @@ cat <<END
 --ifinet6_to_compressed 3ffe04000100f1010000000000000001 40			=3ffe:400:100:f101::1/64
 --addr_to_base85 1080:0:0:0:8:800:200c:417a							=4)+k&C#VzJ4br>0wv%Yp
 --base85_to_addr 4)+k&C#VzJ4br>0wv%Yp								=1080:0:0:0:8:800:200c:417a
---mac_to_eui64 00:50:BF:06:B4:F5									=0:0:0:0:250:bfff:fe06:b4f5
---mac_to_eui64 00:0:F:6:4:5											=0:0:0:0:200:fff:fe06:405
+--mac_to_eui64 00:50:BF:06:B4:F5									=250:bfff:fe06:b4f5
+--mac_to_eui64 00:0:F:6:4:5											=200:fff:fe06:405
+--addr_to_uncompressed --printsuffix ::ffff:1.2.3.4/64				=0:ffff:1.2.3.4
+--addr_to_uncompressed --printsuffix ::ffff:1.2.3.4/63				=0:0:ffff:1.2.3.4
+--addr_to_uncompressed --printsuffix 3ffe:400:100:f101::1/64		=0:0:0:1
+--addr_to_uncompressed --printprefix 3ffe:400:100:f101::1/64		=3ffe:400:100:f101
+--addr_to_uncompressed --printprefix 3ffe:400:100:f101::1/65		=3ffe:400:100:f101:0
 END
 }
 
@@ -70,7 +75,7 @@ testscenarios | while read line; do
 	output="`./ipv6calc $command`"
 	retval=$?
 	if [ $retval -ne 0 ]; then
-		echo "Error executing 'ipv6calc!"
+		echo "Error executing 'ipv6calc'!"
 		exit 1
 	fi
 	# Check result
